abacusai.workflow_node_template — AbacusAI documentation

# abacusai.workflow_node_template

## Classes

`WorkflowNodeTemplate` | A workflow node template.

## Module Contents

class abacusai.workflow_node_template.WorkflowNodeTemplate(client, workflowNodeTemplateId=None, name=None, functionName=None, sourceCode=None, description=None, packageRequirements=None, tags=None, additionalConfigs=None, inputs={}, outputs={}, templateConfigs={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A workflow node template.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - workflowNodeTemplateId (str) – The unique identifier of the workflow node template.

    - name (str) – The name of the workflow node template.

    - functionName (str) – The function name of the workflow node function.

    - sourceCode (str) – The source code of the function that the workflow node template will execute.

    - description (str) – A description of the workflow node template.

    - packageRequirements (list[str]) – A list of package requirements that the node source code may need.

    - tags (dict) – Tags to add to the workflow node template. It contains information on the intended usage of template.

    - additionalConfigs (dict) – Additional configurations for the workflow node template.

    - inputs (WorkflowNodeTemplateInput) – A list of inputs that the workflow node template will use.

    - outputs (WorkflowNodeTemplateOutput) – A list of outputs that the workflow node template will give.

    - templateConfigs (WorkflowNodeTemplateConfig) – A list of template configs that are hydrated into source to get complete code.

  workflow_node_template_id = None
  name = None
  function_name = None
  source_code = None
  description = None
  package_requirements = None
  tags = None
  additional_configs = None
  inputs
  outputs
  template_configs
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict